@@ -1,10 +1,9 @@
 /*  GNU ed - The GNU line editor.
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
-    Free Software Foundation, Inc.
+    Copyright (C) 2006-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -45,7 +44,7 @@
 
 static const char * const Program_name = "GNU Ed";
 static const char * const program_name = "ed";
-static const char * const program_year = "2013";
+static const char * const program_year = "2016";
 static const char * invocation_name = 0;
 
 static bool restricted_ = false;	/* if set, run in restricted mode */
@@ -77,7 +76,7 @@ static void show_help( void )
           "not found, invalid flags, I/O errors, etc), 2 to indicate a corrupt or\n"
           "invalid input file, 3 for an internal consistency error (eg, bug) which\n"
           "caused ed to panic.\n"
-          "\nReport bugs to <bug-ed@gnu.org>.\n"
+          "\nReport bugs to bug-ed@gnu.org\n"
           "Ed home page: http://www.gnu.org/software/ed/ed.html\n"
           "General help using GNU software: http://www.gnu.org/gethelp\n" );
   }
@@ -85,9 +84,9 @@ static void show_help( void )
 
 static void show_version( void )
   {
-  printf( "%s %s\n", Program_name, PROGVERSION );
+  printf( "GNU %s %s\n", program_name, PROGVERSION );
   printf( "Copyright (C) 1994 Andrew L. Moore.\n"
-          "Copyright (C) %s Free Software Foundation, Inc.\n", program_year );
+          "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
   printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
           "This is free software: you are free to change and redistribute it.\n"
           "There is NO WARRANTY, to the extent permitted by law.\n" );
@@ -98,8 +97,7 @@ void show_strerror( const char * const filename, const int errcode )
   {
   if( !scripted_ )
     {
-    if( filename && filename[0] != 0 )
-      fprintf( stderr, "%s: ", filename );
+    if( filename && filename[0] ) fprintf( stderr, "%s: ", filename );
     fprintf( stderr, "%s\n", strerror( errcode ) );
     }
   }
@@ -111,7 +109,7 @@ static void show_error( const char * const msg, const int errcode, const bool he
     {
     fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 ) fprintf( stderr, ": %s", strerror( errcode ) );
-    fprintf( stderr, "\n" );
+    fputc( '\n', stderr );
     }
   if( help )
     fprintf( stderr, "Try '%s --help' for more information.\n",
